=======
History
=======

0.1.0 (2023-08-13)
------------------

* First release on PyPI.


0.1.8 (2023-09-09)
------------------

* Preparations for Open Source Release 
* Simplification of interface with aider
